@@ -14,7 +14,7 @@ use Monitoring::Generator::TestConfig::P1Data;
 use Monitoring::Generator::TestConfig::Modules::Shinken;
 use Monitoring::Generator::TestConfig::ShinkenInitScriptData;
 
-our $VERSION = '0.44';
+our $VERSION = '0.46';
 
 =head1 NAME
 
@@ -663,7 +663,7 @@ sub _set_contacts_cfg {
         'host_notification_options'     => 'd,r',
         'service_notification_commands' => 'notify-service',
         'host_notification_commands'    => 'notify-host',
-        'email'                         => 'nobody\@localhost',
+        'email'                         => 'nobody@localhost',
     };
 
     return($objects);
@@ -948,7 +948,7 @@ sub _get_recreate_pl {
 
     $Data::Dumper::Sortkeys = 1;
     my $conf =  Dumper($self);
-    $conf    =~ s/^\$VAR1\ =\ bless\(\ {//mx;
+    $conf    =~ s/^\$VAR1\ =\ bless\(\ \{//mx;
     $conf    =~ s/},\ 'Monitoring::Generator::TestConfig'\ \);$//mx;
 
     $pl  = <<EOT;
